==> generator-kaokei-1.0.4.tgz: package/generators/vue-web/templates/vue.config.js <==
/* eslint-disable @typescript-eslint/no-var-requires */
const webpack = require('webpack');
const HtmlWebpackPlugin = require('html-webpack-plugin');
const WebpackAliyunOss = require('@hetao/webpack-aliyun-oss');
const SentryCliPlugin = require('@sentry/webpack-plugin');

const pkg = require('./package.json');

const isProd = process.env.NODE_ENV === 'production';

module.exports = {
  crossorigin: 'anonymous',
  publicPath: isProd
    ? 'https://match-ide.pipacoding.com/cdn/<%= appName %>/'
    : '/<%= appName %>/',
  devServer: {
    port: 8080,
    disableHostCheck: true, // solve Invilid host header problem
    hotOnly: true, // 热更新
    proxy: {
      '/activity-manage-system': {
        target: 'https://www.kjcx100.cn',
        changeOrigin: true,
        xfwd: false, // 不添加x-forward，从而避免网关禁止localhost访问
        secure: false,
        logLevel: 'debug',
      },
      '/einstein-logic': {
        target: 'https://www.kjcx100.cn',
        changeOrigin: true,
        xfwd: false,
        secure: false,
        logLevel: 'debug',
      },
    },
  },
  configureWebpack: config => {
    config.plugins.forEach(val => {
      if (val instanceof HtmlWebpackPlugin) {
        val.options.title = '编程演示活动';
      }
    });
    // 忽略掉moment中的所有本地化语言包
    config.plugins.push(new webpack.IgnorePlugin(/^\.\/locale$/, /moment$/));
    if (isProd) {
      config.plugins.push(
        new WebpackAliyunOss({
          from: ['./dist/**', '!./dist/index.html'],
          dist: 'cdn/<%= appName %>',
          region: 'oss-cn-beijing',
          accessKeyId: 'LTAI4G4fFCszooaoTPXc4JU9',
          accessKeySecret: 'BIjHQLZRW6oOto7abA4qLH3xZqLWqK',
          bucket: 'hetao-contest',
          bail: true,
          test: false,
          setHeaders: () => {
            return {
              'Cache-Control': 'max-age=8640000',
            };
          },
        })
      );
      config.plugins.push(
        new SentryCliPlugin({
          include: config.output.path + '/js',
          configFile: '.sentryclirc',
          release: pkg.version,
          environment: process.env.NODE_ENV,
        })
      );
    }
  },
  css: {
    loaderOptions: {
      less: {
        lessOptions: {
          modifyVars: {
            'primary-color': '#1DA57A',
            'link-color': '#1DA57A',
            'border-radius-base': '2px',
          },
          javascriptEnabled: true,
        },
      },
    },
  },
};

==> generator-kaokei-1.0.8.tgz: package/generators/vue-web/templates/vue.config.js <==
/* eslint-disable @typescript-eslint/no-var-requires */
const webpack = require('webpack');
const HtmlWebpackPlugin = require('html-webpack-plugin');
const WebpackAliyunOss = require('@hetao/webpack-aliyun-oss');
const SentryCliPlugin = require('@sentry/webpack-plugin');

const pkg = require('./package.json');

const isProd = process.env.NODE_ENV === 'production';

module.exports = {
  crossorigin: 'anonymous',
  publicPath: isProd
    ? 'https://match-ide.pipacoding.com/cdn/<%= appName %>/'
    : '/<%= appName %>/',
  devServer: {
    port: 8080,
    disableHostCheck: true, // solve Invilid host header problem
    hotOnly: true, // 热更新
    proxy: {
      '/activity-manage-system': {
        target: 'https://www.kjcx100.cn',
        changeOrigin: true,
        xfwd: false, // 不添加x-forward，从而避免网关禁止localhost访问
        secure: false,
        logLevel: 'debug',
      },
      '/einstein-logic': {
        target: 'https://www.kjcx100.cn',
        changeOrigin: true,
        xfwd: false,
        secure: false,
        logLevel: 'debug',
      },
    },
  },
  configureWebpack: config => {
    config.plugins.forEach(val => {
      if (val instanceof HtmlWebpackPlugin) {
        val.options.title = '编程演示活动';
      }
    });
    // 忽略掉moment中的所有本地化语言包
    config.plugins.push(new webpack.IgnorePlugin(/^\.\/locale$/, /moment$/));
    if (isProd) {
      config.plugins.push(
        new WebpackAliyunOss({
          from: ['./dist/**', '!./dist/index.html'],
          dist: 'cdn/<%= appName %>',
          region: 'oss-cn-beijing',
          accessKeyId: 'xxxxxxxxxx',
          accessKeySecret: 'yyyyyyyyyy',
          bucket: 'hetao-contest',
          bail: true,
          test: false,
          setHeaders: () => {
            return {
              'Cache-Control': 'max-age=8640000',
            };
          },
        })
      );
      config.plugins.push(
        new SentryCliPlugin({
          include: config.output.path + '/js',
          configFile: '.sentryclirc',
          release: pkg.version,
          environment: process.env.NODE_ENV,
        })
      );
    }
  },
  css: {
    loaderOptions: {
      less: {
        lessOptions: {
          modifyVars: {
            'primary-color': '#1DA57A',
            'link-color': '#1DA57A',
            'border-radius-base': '2px',
          },
          javascriptEnabled: true,
        },
      },
    },
  },
};
